// Função para ler parâmetros informados pelo iTarefa via URL
// Apesar de não ser obrigatório, será muito útil para capturar os parâmetros
function getParameterByName(name) {
    var match = RegExp('[?&]' + name + '=([^&]*)').exec(window.location.search);
    return match ? decodeURIComponent(match[1].replace(/\+/g, ' ')) : null;
}

// Criando um array com os parâmetros informados pelo iTarefa
// Observe que para cada parâmetro, é realizada a chamada do método getParameterByName, implementado acima
var iLMparameters = {
    iLM_PARAM_ServerToGetAnswerURL: getParameterByName("iLM_PARAM_ServerToGetAnswerURL"),
    iLM_PARAM_SendAnswer: getParameterByName("iLM_PARAM_SendAnswer"),
    iLM_PARAM_AssignmentURL: getParameterByName("iLM_PARAM_AssignmentURL"),
    iLM_PARAM_Assignment: getParameterByName("iLM_PARAM_Assignment"),
    lang: getParameterByName("lang")
};

// Função chamada pelo iTarefa quando o professor finaliza a criação da atividade
// ou quando o aluno finaliza a resolução do exercício
// O retorno é um JSON com os dados do exercício ou da resolução
// Esse retorno será armazenado no banco de dados do Moodle, pelo iTarefa
function getAnswer() {
    // Se o parâmetro "iLM_PARAM_SendAnswer" for false,
    // então trata-se de resolução de atividade
    if (iLMparameters.iLM_PARAM_SendAnswer == 'false') {
        // Montar o retorno da resposta do aluno
        var respostas = Array();
        for (j = 0; j < desafios.length; j++) {
            respostas.push(parseInt($("#resposta_" + j).val()));
        }

        return '[{"respostas": ' + JSON.stringify(respostas) + '}, {"operacao": "' + operacao + '"}, {"parcelas": ' + JSON.stringify(parcelas) + '}, {"desenhos": ' + JSON.stringify(desenhos) + ' }, '
                    + '{"desafios": ' + JSON.stringify(desafios) + '}]';
    } else {
        return JSON.stringify($('form[name="elaborar"]').serializeArray());
    }
}

// Função chamada pelo iTarefa para receber a nota do aluno na atividade
// O retorno é um valor entre 0.0 e 1.0
function getEvaluation() {
    if (iLMparameters.iLM_PARAM_SendAnswer == 'false') {
        // Calcula a nota do aluno:

        // Como a nota vai de 0 a 1, calculamos um valor unitário para cada acerto:
        var valor_cada_acerto = 1 / desafios.length;

        // Agora, verificamos o total de acertos do aluno:
        var acertos = 0;
        for (i = 0; i < desafios.length; i++) {

            var temp = parcelas[desafios[i][0]];
            for (j = 1; j < desafios[i].length; j++) {
                switch(operacao) {
                    case "ADI": temp += parcelas[desafios[i][j]];
                        break;
                    case "SUB": temp -= parcelas[desafios[i][j]];
                        break;
                    case "MUL": temp *= parcelas[desafios[i][j]];
                        break;
                    case "DIV": temp /= parcelas[desafios[i][j]];
                        break;
                }
            }
            var resposta = parseInt($("#resposta_" + i).val().trim());            
            if (resposta == temp) {
                acertos ++;
            }
        }
        // Cálculo da nota: o produto do valor de cada desafio pelo número de acertos:
        var nota = valor_cada_acerto * acertos;

        // A chamada do método abaixo é obrigatória!
        // Observe que a chamada parte do iLM para o iTarefa
        parent.getEvaluationCallback(nota);
    }
}


// Função para que o iMA leia os dados da atividade fornecidos pelo iTarefa
function getiLMContent() {

    // O parâmetro "iLM_PARAM_Assignment" fornece o URL do endereço que deve ser
    // requisitado via AJAX para a captura dos dados da atividade
    $.get(iLMparameters.iLM_PARAM_Assignment, function (d) {

        // Uma vez que os dados foram recebidos, o método "organizaAtividade" é chamado.
        // Observe que esse método faz parte do arquivo js/iarithmetic-functions.js
        organizaAtividade(JSON.parse(d));

    });
}

// Adicionamos a diretiva .ready(), para que quando a página HTML estiver carregada,
// seja verificado qual a visualização deve ser apresentada: se a área de construção
// de atividade ou de resolução. E no caso de ser resolução, os dados da atividade
// precisam ser consultados, pelo método implementado acima, o getiLMContent()
$(document).ready(function() {

    // Se iLM_PARAM_SendAnswer for false, então trata-se de resolução de atividade,
    // portanto, a "DIV" de resolução é liberada
    if (iLMparameters.iLM_PARAM_SendAnswer == 'false') {
        $('.resolucao').css("display","block");
        getiLMContent();
    } else {
        // Caso não esteja em modo de resolução de atividade, a visualização no momento
        // é para a elaboração de atividade:
        $('.elaboracao').css("display","block");
    }
});